@@ -28,7 +28,7 @@ from typing import List
 
 import django.utils.timezone
 import pytz
-from django.core.exceptions import ValidationError
+from django.core import exceptions
 from django.conf import settings
 from django.db import models, transaction
 from django.db.models.base import ModelBase
@@ -39,6 +39,13 @@ from timezone_field import TimeZoneField
 
 from .time_span import AbstractTimeSpan, TimeSpan, PaddedTimeSpan
 
+# this moved in Django 3
+FieldDoesNotExist = (
+    exceptions.FieldDoesNotExist
+    if hasattr(exceptions, "FieldDoesNotExist")
+    else models.FieldDoesNotExist
+)
+
 __all__ = [
     "AbstractAvailability",
     "AbstractAvailabilityOccurrence",
@@ -69,8 +76,7 @@ class TimeSlot(models.Model):
 
 # abstract model classes
 class Meta(ModelBase):
-    """A metaclass for abstract models that orchestrates the relationships
-    """
+    """A metaclass for abstract models that orchestrates the relationships"""
 
     def __new__(mcs, name, bases, attrs):
         model = super().__new__(mcs, name, bases, attrs)
@@ -84,13 +90,23 @@ class Meta(ModelBase):
                     related_name = "availability_occurrences"
                 elif b.__name__ == "AbstractTimeSlot":
                     related_name = "time_slots"
+                    model.add_to_class(
+                        "padding_for",
+                        models.ForeignKey(
+                            model.__name__,
+                            blank=True,
+                            null=True,
+                            on_delete=models.CASCADE,
+                            related_name="padded_by",
+                        ),
+                    )
                 elif b.__name__ == "AbstractBooking":
                     related_name = "bookings"
             field_name = Meta.get_schedule_field(model)
             schedule_cls = Meta.get_schedule_model(model)
             try:
                 meta.get_field(field_name)
-            except models.FieldDoesNotExist:
+            except FieldDoesNotExist:
                 model.add_to_class(
                     field_name,
                     models.ForeignKey(
@@ -136,7 +152,7 @@ class OccurrenceMeta(Meta):
             avail_cls = OccurrenceMeta.get_availability_model(model)
             try:
                 meta.get_field(field_name)
-            except models.FieldDoesNotExist:
+            except FieldDoesNotExist:
                 model.add_to_class(
                     field_name,
                     models.ForeignKey(
@@ -175,7 +191,7 @@ class TimeSlotMeta(Meta):
             booking_cls = TimeSlotMeta.get_booking_model(model)
             try:
                 meta.get_field(field_name)
-            except models.FieldDoesNotExist:
+            except FieldDoesNotExist:
                 model.add_to_class(
                     field_name,
                     models.ForeignKey(
@@ -401,14 +417,6 @@ class AbstractTimeSlot(models.Model, AbstractTimeSpan, metaclass=TimeSlotMeta):
     end = models.DateTimeField(db_index=True)  # type: datetime
     busy = models.BooleanField(default=False, db_index=True)
 
-    padding_for = models.ForeignKey(
-        "TimeSlot",
-        blank=True,
-        null=True,
-        on_delete=models.CASCADE,
-        related_name="padded_by",
-    )
-
     def __str__(self):
         return "TimeSlot object ({}:{})".format(self.id, AbstractTimeSpan.__str__(self))
 
@@ -540,7 +548,7 @@ class AbstractBooking(models.Model, metaclass=Meta):
                     and free_spans[0].start <= span.start
                     and free_spans[0].end >= span.end
                 ):
-                    raise ValidationError(
+                    raise exceptions.ValidationError(
                         self.un_free_message.format(start=span.start, end=span.end)
                     )
 
@@ -562,7 +570,7 @@ class AbstractBooking(models.Model, metaclass=Meta):
                     )
                     busy_q = busy_q.exclude(ex_q)
                 if busy_q.exists():
-                    raise ValidationError(
+                    raise exceptions.ValidationError(
                         self.busy_message.format(start=span.start, end=span.end)
                     )
 
