@@ -74,7 +74,7 @@ class BookingTests(BaseCase):
         # * 10:30-11  padding
         # * 11-12     booking
         # * 12-12:30  padding
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         times = (
             (time(10, 30), time(11), True),
             (time(11), time(12), True),
@@ -125,7 +125,7 @@ class BookingTests(BaseCase):
         # * 10-11     booking
         # * 11-11:30  padding
 
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         times = (
             (time(9, 30), time(10), True),
             (time(10), time(11), True),
@@ -165,7 +165,7 @@ class BookingTests(BaseCase):
         multiple_booking.allow_multiple_bookings = True
         multiple_booking.full_clean()
         multiple_booking.save()
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         # Now we should be able to create another booking at the same time
         second_multiple_booking = models.Booking(
             guest=self.second_guest,
@@ -192,7 +192,7 @@ class BookingTests(BaseCase):
             second_multiple_booking.cancel_with_reason("foo", "bar")
             second_multiple_booking.full_clean()
             second_multiple_booking.save()
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         times = (
             (time(10, 30), time(11), True),
             (time(11), time(12, 00), True),  # original booking slot
@@ -210,7 +210,7 @@ class BookingTests(BaseCase):
         multiple_booking.allow_multiple_bookings = True
         multiple_booking.full_clean()
         multiple_booking.save()
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         times = (
             (time(8, 30), time(9), True),
             (time(9), time(10), False),  # multiple booking slot
@@ -245,7 +245,7 @@ class BookingTests(BaseCase):
         )
         second_multiple_booking.full_clean()
         second_multiple_booking.save()
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         times = (
             (time(8, 30), time(9), True),  # padding 1
             (time(8, 30), time(9), True),  # padding 2
@@ -285,7 +285,7 @@ class BookingTests(BaseCase):
             self.booking.save()
         # we've cancelled all the times, so there should be no slots
         times = []
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         self.check_time_slots(times, slots)
 
 
@@ -317,7 +317,7 @@ class AdvancedBookingTests(BaseCase):
             timezone=str(self.timezone),
         )
         avail.recreate_occurrences(self.date, self.date + timedelta(days=10))
-        slots = models.TimeSlot.objects.filter(schedule=self.host)
+        slots = models.Slot.objects.filter(schedule=self.host)
         times = []
         self.check_time_slots(times, slots)
 
@@ -328,7 +328,7 @@ class AdvancedBookingTests(BaseCase):
         booking = models.Booking.objects.create(
             guest=self.guest, schedule=self.host, requested_time_1=booking_time
         )
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         #  They'll be the usual 3 slots
         # * 10:30-11
         # * 11-12
@@ -343,12 +343,12 @@ class AdvancedBookingTests(BaseCase):
         booking.padding = timedelta(hours=1)
         booking.full_clean()
         booking.save()
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         # this should still be the same as before because the booking shouldn't
         # necessarily know about the padding
         self.check_time_slots(times, slots)
         booking._padding_changed()
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         #  Now the padding will be 1 hour
         # * 8-10
         # * 10-11
@@ -380,7 +380,7 @@ class AdvancedBookingTests(BaseCase):
 
         for avail in (first_avail, second_avail):
             avail.recreate_occurrences(self.date, self.date + timedelta(days=10))
-        slots = models.TimeSlot.objects.filter(schedule=self.host)
+        slots = models.Slot.objects.filter(schedule=self.host)
         times = []
         self.check_time_slots(times, slots)
 
@@ -400,7 +400,7 @@ class AdvancedBookingTests(BaseCase):
         )
         b.full_clean()
         b.save()
-        slots = models.TimeSlot.objects.filter(schedule=self.host).order_by("start")
+        slots = models.Slot.objects.filter(schedule=self.host).order_by("start")
         times = (
             (time(10, 30), time(11), True),  # first time pad
             (time(11), time(12), True),  # first time
